clear all; close all

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
% FIG2
%   
%=========================================================================================================

% download frezchem phase diagram
fc = read_frezchem

T_eutectic = -36.2

%==============================================================================
% Computations
%==============================================================================

% 1) Solid salt fraction from Assur (1958)
% Table 3, page 124
% fsm was derived in data_Assur58_phase_diagram.m
% the mass of salt in all minerals was obtained, then summed, then divided by the 
% reference salinity of 34.325 g/kg
%
T_Assur = 0.:-2:-54.;
fsm_Assur = ...
     [ 0. 0. 0.0010    0.0019    0.0025    0.0537    0.0789    0.0902    0.0974    0.1024 ...
       0.1069    0.1111    0.3394    0.5694    0.6758    0.7308    0.7613    0.7824    0.7959    0.8070 ...
       0.8176    0.8263    0.8654    0.9143    0.9413    0.9569    0.9661    0.9717 ];

% 2) Solid salt fraction from FREZCHEM runs
   
T_test  = 0.:-0.01:-54.;
f_sm_fc = fs_minerals(T_test,2,T_eutectic);


% 3) From Butler formula (GCA 2016, table 4)
% (Mirability only)
T_Butler = -6.4+273.15:-2.:-22.9+273.15;
zT2 = T_Butler .* T_Butler;
zT3 = T_Butler .* zT2;
zT4 = T_Butler .* zT3;

zA = -1.60988574e6;
zB = 2.51374843e4;
zC = -1.47193536e2;
zD = 3.83078252e-1;
zE = -3.73882534e-4;

mirabilite_butler = zA + zB * T_Butler + zC * zT2 + zD * zT3 + zE * zT4 % mass of mirabilite

% fraction of salt in mirabilite
mNa2SO4 = 2. * 22.98976928 + 96.06260000
mH2O = 18.0152682
salt_fraction_mirabilite = mNa2SO4 / ( mNa2SO4 + 10. * mH2O )

f_sm_mirabilite_butler = mirabilite_butler * salt_fraction_mirabilite / 35.165

%==============================================================================
% Plots
%==============================================================================

figure; hold on; box on;

plot(T_Assur,fsm_Assur,'r--', 'LineWidth', 2);%, 'MarkerFaceColor', 'k');
plot(T_test,f_sm_fc,'k', 'LineWidth', 2, 'Color', [0.5 0.5 0.5])
plot((T_Butler-273.15),f_sm_mirabilite_butler,'ksq', 'MarkerFaceColor', [0. 0. 1.], 'MarkerSize', 10)
xlim([-40 0.])
ylim([0. 1.])
legend('Assur (1958)', 'FREZCHEM', 'Butler et al (2016a) - mirabilite only')

xlabel('T(C)')
ylabel('f_{sm}(T)')
set(gca,'fontsize', 16)
set(gca, 'FontName', 'Helvetica LT Std')