clear all; close all

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
% FIG5a
%   
%=========================================================================================================
T_eutectic = -36.2;

%---------------------------------------------------------------------------------------------------------
%
% Load data and retrieved liquid H2O mass fractions
%
%---------------------------------------------------------------------------------------------------------

% Load RK66 NMR retrievals
[ S_RK66_exp1, T_RK66_exp1, phi_H2O_br_RK66_exp1, ...
  S_RK66_exp2, T_RK66_exp2, phi_H2O_br_RK66_exp2] = phi_H2O_br_obs;

% FREZCHEM phase diagram
fc               = read_frezchem;
T_fc             = fc.T;
S_fc             = fc.SA;
phi_H2O_liq_fc   = fc.phi_H2O_liq;
[TT_fc,SS_fc]    = meshgrid(T_fc,S_fc);

% S-T arrays for retrievals
T          = T_fc'
S          = [ 10.022 35.035 ];
[ TT, SS ] = meshgrid(T,S);

% mTEOS-10 + minerals
Sbr_TEOS10     = S_liquidus(TT,5);
phi_liq_TEOS10 = phi_br(SS, TT, 5, 2, 0, T_eutectic);
phi_H2O_liq_TEOS10 = phi_liq_TEOS10 .* ( 1. - Sbr_TEOS10 / 1000. );

% Assur 58
Sbr_BL99 = S_liquidus(TT,1);
phi_liq_BL99 = phi_br(SS, TT, 1, 0, 0, T_eutectic);
phi_H2O_liq_BL99 = phi_liq_BL99 .* ( 1. - Sbr_BL99 / 1000. );

% POLY3
Sbr_3o = S_liquidus(TT,3);
phi_liq_3o = phi_br(SS, TT, 3, 0, 0, T_eutectic);
phi_H2O_liq_3o = phi_liq_3o .* ( 1. - Sbr_3o / 1000. );

% CW86
Sbr_CW = S_liquidus(TT,6);
phi_liq_CW = phi_br(SS, TT, 6, 0, 0, T_eutectic);
phi_H2O_liq_CW = phi_liq_CW .* ( 1. - Sbr_CW / 1000. );

% FREZCHEM (calculated)
Sbr_fc2_ss            = S_liquidus(TT,7);
phi_liq_fc2_ss        = phi_br(SS, TT, 7, 2, 0, T_eutectic);
phi_H2O_liq_fc2_ss    = phi_liq_fc2_ss .* ( 1. - Sbr_fc2_ss / 1000. );

%---------------------------------------------------------------------------------------------------------
%
% Plot absolute values
%
%---------------------------------------------------------------------------------------------------------

figure; hold on; box on;

% Calculated FREZCHEM
zaddr = find(double(int16(T(1,:)))./T(1,:)==1);
h3 = plot( T(zaddr), phi_H2O_liq_fc2_ss(1,zaddr)*1000. , 'ko', 'MarkerFaceColor', [0.5 0.5 0.5], 'MarkerSize', 8.);
h4 = plot( T(zaddr), phi_H2O_liq_fc2_ss(2,zaddr)*1000. , 'ko', 'MarkerFaceColor', [0.5 0.5 0.5], 'MarkerSize', 8.);

% Raw FREZCHEM
%plot( T_fc(zaddr) , phi_H2O_liq_fc(36,zaddr)*S_RK66_exp1/35.*1000. , 'bo', 'MarkerFaceColor', [0.0 0.0 0.5], 'MarkerSize', 4.);
%plot( T_fc(zaddr) , phi_H2O_liq_fc(11,zaddr)*S_RK66_exp2/10.*1000. , 'bo', 'MarkerFaceColor', [0.0 0.0 0.5], 'MarkerSize', 4.);

% BL99
h9 = plot(T,phi_H2O_liq_BL99(1,:)*1000., 'r--', 'LineWidth', 1);
h10 = plot(T,phi_H2O_liq_BL99(2,:)*1000., 'r--', 'LineWidth', 1);

% POLY3
h11 = plot(T,phi_H2O_liq_3o(1,:)*1000., 'k', 'LineWidth', 1.5);
h12 = plot(T,phi_H2O_liq_3o(2,:)*1000., 'k', 'LineWidth', 1.5);

% mTEOS-10 + FREZCHEM minerals
h5 = plot(T,phi_H2O_liq_TEOS10(1,:)*1000., 'b', 'LineWidth', 1.5);
h6 = plot(T,phi_H2O_liq_TEOS10(2,:)*1000., 'b', 'LineWidth', 1.5);

% CW83+86
zcolor = [ 1. 0.82 0.13 ];
h7 = plot(T,phi_H2O_liq_CW(1,:)*1000., 'Color', zcolor, 'LineWidth', 1.5);
h8 = plot(T,phi_H2O_liq_CW(2,:)*1000., 'Color', zcolor, 'LineWidth', 1.5);

% RMN data from RK66
h1 = plot( T_RK66_exp1 , phi_H2O_br_RK66_exp1, 'ksq', 'MarkerFaceColor', 'r', 'MarkerSize', 10.);
h2 = plot( T_RK66_exp2 , phi_H2O_br_RK66_exp2, 'ksq', 'MarkerFaceColor', 'b', 'MarkerSize', 10.);

xlabel('T (C)')
ylabel('\phi_{br}^{H_2O} (g/kg)')
set(gca,'yscale','log')
set(gca,'fontsize', 20.)
set(gca, 'FontName', 'Helvetica LT Std')
xlim([-36 0.])
ylim([1. 1000.])

legend([h1 h2 h3 h9    h11 h5 h7], ...
    'NMR obs (RK66), S=35.035 g/kg', ...
    'NMR obs (RK66), S=10.022 g/kg', ...
    'FREZCHEM', 'S_{br}: linear (A58); f_{min} = 0', ...
                'S_{br}: POLY3; f_{min} = 0 ', ...
                'S_{br}: mTEOS-10; f_{min}: FREZCHEM', ...
                'S_{br}: CW86; \phi^v_{br}: CW83')