clear all; close all

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
% FIG5b
%   
%=========================================================================================================


T_eutectic = -36.2;

unit_fac   = 1000.; % 1000 for g/kg, 100 for %

if (unit_fac == 1000); c_unit = 'g/kg'; elseif ( unit_fac == 100. ); c_unit = '%'; end

%---------------------------------------------------------------------------------------------------------
%
% Load RK66 data
%
%---------------------------------------------------------------------------------------------------------

% Load RK66 NMR retrievals
[ S_RK66_exp1, T_RK66_exp1, phi_H2O_br_RK66_exp1, ...
  S_RK66_exp2, T_RK66_exp2, phi_H2O_br_RK66_exp2] = phi_H2O_br_obs;

% Assemble arrays
T = [ T_RK66_exp1 T_RK66_exp2 ];
zs1 = T_RK66_exp1; zs1(:) = S_RK66_exp1;
zs2 = T_RK66_exp2; zs2(:) = S_RK66_exp2;
S = [ zs1 zs2 ];

% Convert into absolute units (kg/kg)
phi_H2O_liq_RK66 = [ phi_H2O_br_RK66_exp1 phi_H2O_br_RK66_exp2 ] / 1000.;

% Address experiments
zaddr       = find( T >= T_eutectic);
zaddr_exp1  = find( T >= T_eutectic & S == S_RK66_exp1 );
zaddr_exp2  = find( T >= T_eutectic & S == S_RK66_exp2 );

zs = size(T) ; N_RK66 = zs(2);
           
%---------------------------------------------------------------------------------------------------------
%
% Liquid H2O mass fraction retrievals
%
%---------------------------------------------------------------------------------------------------------

% FREZCHEM, raw
fc = read_frezchem;
T_fc = fc.T;
S_fc = fc.SA;
phi_H2O_liq_fc_raw  = fc.phi_H2O_liq;

% FREZCHEM, calculated
phi_H2O_liq_fc = zeros(N_RK66);
phi_H2O_liq_fc(zaddr_exp1) = pchip(T_fc,phi_H2O_liq_fc_raw(36,:),T(zaddr_exp1)) * S_RK66_exp1 / 35.;
phi_H2O_liq_fc(zaddr_exp2) = pchip(T_fc,phi_H2O_liq_fc_raw(11,:),T(zaddr_exp2)) * S_RK66_exp2 / 10.;

% BL99, no minerals
Sbr_BL99          = S_liquidus(T,1);
phi_liq_BL99      = phi_br(S, T, 1, 0, 0, T_eutectic);
phi_H2O_liq_BL99  = phi_liq_BL99 .* ( 1. - Sbr_BL99 / 1000. );

% NW09, no minerals
Sbr_NW09          = S_liquidus(T,2);
phi_liq_NW09      = phi_br(S, T, 2, 0, 0, T_eutectic);
phi_H2O_liq_NW09  = phi_liq_NW09 .* ( 1. - Sbr_NW09 / 1000. );

% POLY3, no minerals
Sbr_3o            = S_liquidus(T,3);
phi_liq_3o        = phi_br(S, T, 3, 0, 0, T_eutectic);
phi_H2O_liq_3o    = phi_liq_3o .* ( 1. - Sbr_3o / 1000. );

% POLY3 + FREZCHEM minerals
Sbr_3o_ss         = S_liquidus(T,3);
phi_liq_3o_ss     = phi_br(S, T, 3, 2, 0, T_eutectic);
phi_H2O_liq_3o_ss = phi_liq_3o_ss .* ( 1. - Sbr_3o_ss / 1000. );

% mTEOS-10 + FREZCHEM minerals
Sbr_TEOS10_ss         = S_liquidus(T,5);
phi_liq_TEOS10_ss     = phi_br(S, T, 5, 2, 0, T_eutectic);
phi_H2O_liq_TEOS10_ss = phi_liq_TEOS10_ss .* ( 1. - Sbr_TEOS10_ss / 1000. );

% FREZCHEM liquidus, minerals
Sbr_fc2_ss            = S_liquidus(T,7);
phi_liq_fc2_ss        = phi_br(S, T, 7, 2, 0, T_eutectic);
phi_H2O_liq_fc2_ss    = phi_liq_fc2_ss .* ( 1. - Sbr_fc2_ss / 1000. );

% CW
Sbr_CW                = S_liquidus(T,6);
phi_liq_CW            = phi_br(S, T, 6, 0, 0, T_eutectic);
phi_H2O_liq_CW        = phi_liq_CW .* ( 1. - Sbr_CW / 1000. );

%---------------------------------------------------------------------------------------------------------
%
% Plot differences
%
%---------------------------------------------------------------------------------------------------------%

figure; box on

subplot(5,1,1); hold on; box on; grid on
zerr_abs_exp1 = ( phi_H2O_liq_fc2_ss(zaddr_exp1) - phi_H2O_liq_RK66(zaddr_exp1) )*unit_fac;
zerr_abs_exp2 = ( phi_H2O_liq_fc2_ss(zaddr_exp2) - phi_H2O_liq_RK66(zaddr_exp2) )*unit_fac;
h1 = plot(T(zaddr_exp1), zerr_abs_exp1, 'ksq', 'MarkerFaceColor', 'r'); 
h2 = plot(T(zaddr_exp2), zerr_abs_exp2, 'ksq', 'MarkerFaceColor', 'b'); 
legend([h1 h2], {'S=35.035 g/kg', 'S=10.022 g/kg'})
%xlabel('T(C)'); ylabel('absolute error'); 
title('FREZCHEM')
xlim([-36. 0.]); ylim([-100. 100.]);
set(gca,'fontsize', 12)
set(gca, 'FontName', 'Helvetica LT Std')

subplot(5,1,2); hold on;  box on; grid on
zerr_abs_exp1 = ( phi_H2O_liq_BL99(zaddr_exp1) - phi_H2O_liq_RK66(zaddr_exp1) )*unit_fac;
zerr_abs_exp2 = ( phi_H2O_liq_BL99(zaddr_exp2) - phi_H2O_liq_RK66(zaddr_exp2) )*unit_fac;
plot(T(zaddr_exp1), zerr_abs_exp1, 'ksq', 'MarkerFaceColor', 'r'); 
plot(T(zaddr_exp2), zerr_abs_exp2, 'ksq', 'MarkerFaceColor', 'b'); 
%xlabel('T(C)'); ylabel('absolute error'); 
title('Linear liquidus (no minerals)')
xlim([-36. 0.]); ylim([-100. 100.]);
set(gca,'fontsize', 12)
set(gca, 'FontName', 'Helvetica LT Std')

subplot(5,1,3); hold on;  box on; grid on
zerr_abs_exp1 = ( phi_H2O_liq_3o(zaddr_exp1) - phi_H2O_liq_RK66(zaddr_exp1) )*unit_fac;
zerr_abs_exp2 = ( phi_H2O_liq_3o(zaddr_exp2) - phi_H2O_liq_RK66(zaddr_exp2) )*unit_fac;
plot(T(zaddr_exp1), zerr_abs_exp1, 'ksq', 'MarkerFaceColor', 'r'); 
plot(T(zaddr_exp2), zerr_abs_exp2, 'ksq', 'MarkerFaceColor', 'b'); 
%xlabel('T(C)'); ylabel('absolute error'); 
ylabel('\phi^{H_2O}_l(S^{NMR},T^{NMR}) - \phi^{H_2O,NMR}_l (g/kg)');
title('3-o. liquidus (no minerals)')
xlim([-36. 0.]); ylim([-100. 100.]);
set(gca,'fontsize', 12)
set(gca, 'FontName', 'Helvetica LT Std')

subplot(5,1,4); hold on;  box on; grid on
zerr_abs_exp1 = ( phi_H2O_liq_TEOS10_ss(zaddr_exp1) - phi_H2O_liq_RK66(zaddr_exp1) )*unit_fac;
zerr_abs_exp2 = ( phi_H2O_liq_TEOS10_ss(zaddr_exp2) - phi_H2O_liq_RK66(zaddr_exp2) )*unit_fac;
plot(T(zaddr_exp1), zerr_abs_exp1, 'ksq', 'MarkerFaceColor', 'r'); 
plot(T(zaddr_exp2), zerr_abs_exp2, 'ksq', 'MarkerFaceColor', 'b'); 
%xlabel('T(C)'); ylabel('absolute error'); 
title('TEOS-10 modified liquidus + minerals')
xlim([-36. 0.]); ylim([-100. 100.]);
set(gca,'fontsize', 12)
set(gca, 'FontName', 'Helvetica LT Std')

subplot(5,1,5); hold on;  box on; grid on
zerr_abs_exp1 = ( phi_H2O_liq_CW(zaddr_exp1) - phi_H2O_liq_RK66(zaddr_exp1) )*unit_fac;
zerr_abs_exp2 = ( phi_H2O_liq_CW(zaddr_exp2) - phi_H2O_liq_RK66(zaddr_exp2) )*unit_fac;
plot(T(zaddr_exp1), zerr_abs_exp1, 'ksq', 'MarkerFaceColor', 'r'); 
plot(T(zaddr_exp2), zerr_abs_exp2, 'ksq', 'MarkerFaceColor', 'b'); 
xlabel('T(C)'); title('CW83/86')
xlim([-36. 0.]); ylim([-100. 100.]);
set(gca,'fontsize', 12)
set(gca, 'FontName', 'Helvetica LT Std')
plot([-2 -2 ], [-500 500], 'k--')

% draw rectangles
v = [-2. -500.; 0. -500.; 0. 500.; -2. 500.];
f = [1 2 3 4];
hpatch = patch('Faces',f,'Vertices',v,'FaceColor', [0.5 0. 0.], 'FaceAlpha', 0.1)
hh1 = hatchfill(hpatch, 'single', -45, 3);

v = [-36. -500.; -30. -500.; -30. 500.; -36. 500.];
f = [1 2 3 4];
hpatch = patch('Faces',f,'Vertices',v,'FaceColor', [0.5 0. 0.], 'FaceAlpha', 0.1)
hh1 = hatchfill(hpatch, 'single', -45, 3);