clear all; close all

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
% FIG6
%   
%=========================================================================================================

T_eutectic = -36.2000000000000;

fc            = read_frezchem;
T             = fc.T;
S             = fc.SA;
Sbr           = fc.S_br;
phi           = fc.phi_liq;
[TT,SS]       = meshgrid(T,S);

phi_BL99      = phi_br(SS,TT,1,0,0,T_eutectic); % linear liquidus, no solid salt
phi_NW09      = phi_br(SS,TT,2,0,0,T_eutectic); % NW09 liquidus, no solid salt
phi_ML        = phi_br(SS,TT,3,0,0,T_eutectic); % new polynom liquidus, no solid salt

phi_ML_ss     = phi_br(SS,TT,3,2,0,T_eutectic); % new polynom liquidus, solid salt
phi_TEOS10_ss = phi_br(SS,TT,5,2,0,T_eutectic); % TEOS-10 liquidus, solid salt

phi_CW83      = phi_br(SS,TT,6,0,0,T_eutectic); % Cox and Weeks brine mass fraction

%=========================================================================================================
%
% PLOTS
%
%=========================================================================================================

unit_fac = 1000.; % 1000. for g/kg or 100 for %
phi_levels = [ 0. 0.01 0.025 0.05 0.075 0.1 0.15 0.2 0.4 1.0 ];
diff_levels = [-0.06 -0.05 -0.04 -0.03 -0.02 -0.01 -0.005 -0.001 0. 0.001 0.005 0.01 0.02 0.03 0.04 0.05 0.06];

figure;


% colormap
Nc = 100;
c = flipud(bone(Nc));
colormap(c(:,:));
c_levels = 0:unit_fac/Nc:unit_fac;

fs = 12; %font size

subplot(2,5,1); hold on; %--- FREZCHEM
title ('FREZCHEM')
[C1,h1] = contourf(TT,SS,phi*unit_fac,c_levels,'LineColor','none');
[C1,h1] = contour(TT,SS,phi*unit_fac,phi_levels*unit_fac,'LineColor', 'k');
clabel(C1, h1, 'LabelSpacing', 200)%,'FontSize',8);
xlabel('T (C)')
ylabel('S (g/kg)')
set(gca,'yscale','log')
set(gca,'fontsize', fs)
set(gca, 'FontName', 'Helvetica LT Std')
xlim([-36 0.])
ylim([0. 40.])
yticks([1. 5. 10. 20. 40.])
xticks([-36 -30. -20. -10. 0.])

subplot(2,5,2); hold on; %--- BL99
title ('A58 liquidus, no minerals')
[C1,h1] = contourf(TT,SS,phi_BL99*unit_fac,c_levels,'LineColor', 'none');
[C1,h1] = contour(TT,SS,phi_BL99*unit_fac,phi_levels*unit_fac,'LineColor', 'k');
clabel(C1, h1, 'LabelSpacing', 200)%,'FontSize',8);
xlabel('T (C)')
ylabel('S (g/kg)')
set(gca,'yscale','log')
set(gca,'fontsize', fs)
set(gca, 'FontName', 'Helvetica LT Std')
xlim([-36 0.])
ylim([0. 40.])
yticks([1. 5. 10. 20. 40.])
xticks([-36 -30. -20. -10. 0.])

subplot(2,5,3); hold on; %--- New polynom
title ('POLY3 liquidus, no minerals')
[C1,h1] = contourf(TT,SS,phi_ML*unit_fac,c_levels,'LineColor', 'none');
[C1,h1] = contour(TT,SS,phi_ML*unit_fac,phi_levels*unit_fac,'LineColor', 'k');
clabel(C1, h1, 'LabelSpacing', 200)%,'FontSize',8);
xlabel('T (C)')
ylabel('S (g/kg)')
set(gca,'yscale','log')
set(gca,'fontsize', fs)
set(gca, 'FontName', 'Helvetica LT Std')
xlim([-36 0.])
ylim([0. 40.])
yticks([1. 5. 10. 20. 40.])
xticks([-36 -30. -20. -10. 0.])

subplot(2,5,4); hold on; %--- Modified TEOS-10 + salt
title ('mTEOS-10 liquidus, minerals')
[C1,h1] = contourf(TT,SS,phi_TEOS10_ss*unit_fac,c_levels,'LineColor', 'none');
[C1,h1] = contour(TT,SS,phi_TEOS10_ss*unit_fac,phi_levels*unit_fac,'LineColor', 'k');
clabel(C1, h1, 'LabelSpacing', 200)%,'FontSize',8);
xlabel('T (C)')
ylabel('S (g/kg)')
set(gca,'yscale','log')
set(gca,'fontsize', fs)
set(gca, 'FontName', 'Helvetica LT Std')
xlim([-36 0.])
ylim([0. 40.])
yticks([1. 5. 10. 20. 40.])
xticks([-36 -30. -20. -10. 0.])


subplot(2,5,5); hold on; %--- CW83
title ('CW83')
[C1,h1] = contourf(TT,SS,phi_CW83*unit_fac,c_levels,'LineColor', 'none');
[C1,h1] = contour(TT,SS,phi_CW83*unit_fac,phi_levels*unit_fac,'LineColor', 'k');
clabel(C1, h1, 'LabelSpacing', 200)%,'FontSize',8);
xlabel('T (C)')
ylabel('S (g/kg)')
set(gca,'yscale','log')
set(gca,'fontsize', fs)
set(gca, 'FontName', 'Helvetica LT Std')
xlim([-36 0.])
ylim([0. 40.])
yticks([1. 5. 10. 20. 40.])
xticks([-36 -30. -20. -10. 0.])

plot([-2 -2], [0.3 40], 'k--')
plot([-30 -30], [0.3 40], 'k--')

%------------------------------------------------------------------------------
% Differences
%------------------------------------------------------------------------------

%colormap(jet)
zcmin    = min(diff_levels);
zcmax    = max(diff_levels);
zdelta   = (zcmax - zcmin)/(Nc-1);
c_levels = zcmin:zdelta:zcmax;

subplot(2,5,7); hold on; %--- BL99 - FREZCHEM
%title ('Diff wrt FREZCHEM')
%[C1,h1] = contourf(TT,SS,(phi_BL99-phi)*unit_fac,c_levels*unit_fac,'LineColor', 'none');
[C1,h1] = contour(TT,SS,(phi_BL99-phi)*unit_fac,diff_levels*unit_fac,'LineColor', 'k');
clabel(C1, h1)%, 'LabelSpacing', 200)%,'FontSize',8);
%colorbar
xlabel('T (C)')
ylabel('S (g/kg)')
set(gca,'yscale','log')
set(gca,'fontsize', fs)
set(gca, 'FontName', 'Helvetica LT Std')
xlim([-36 0.])
ylim([0. 40.])
yticks([1. 5. 10. 20. 40.])
xticks([-36 -30. -20. -10. 0.])


subplot(2,5,8); hold on; %--- BL99 - FREZCHEM
%title ('Diff wrt FREZCHEM')
%[C1,h1] = contourf(TT,SS,(phi_ML-phi)*unit_fac,c_levels*unit_fac,'LineColor', 'none');
[C1,h1] = contour(TT,SS,(phi_ML-phi)*unit_fac,diff_levels*unit_fac,'LineColor', 'k');
clabel(C1, h1)%, 'LabelSpacing', 200)%,'FontSize',8);
%colorbar
xlabel('T (C)')
ylabel('S (g/kg)')
set(gca,'yscale','log')
set(gca,'fontsize', fs)
set(gca, 'FontName', 'Helvetica LT Std')
xlim([-36 0.])
ylim([0. 40.])
yticks([1. 5. 10. 20. 40.])
xticks([-36 -30. -20. -10. 0.])

subplot(2,5,9); hold on; %--- mTEOS10+ss - FREZCHEM
%title ('Diff wrt FREZCHEM')
%[C1,h1] = contourf(TT,SS,(phi_TEOS10_ss-phi)*unit_fac,c_levels*unit_fac,'LineColor', 'none');
[C1,h1] = contour(TT,SS,(phi_TEOS10_ss-phi)*unit_fac,diff_levels*unit_fac,'LineColor', 'k');
clabel(C1, h1)%, 'LabelSpacing', 200)%,'FontSize',8);
%colorbar
xlabel('T (C)')
ylabel('S (g/kg)')
set(gca,'yscale','log')
set(gca,'fontsize', fs)
set(gca, 'FontName', 'Helvetica LT Std')
xlim([-36 0.])
ylim([0. 40.])
yticks([1. 5. 10. 20. 40.])
xticks([-36 -30. -20. -10. 0.])


subplot(2,5,10); hold on; %--- CW88 - FREZCHEM
%title ('Diff wrt FREZCHEM')
%[C1,h1] = contourf(TT,SS,(phi_CW83-phi)*unit_fac,c_levels*unit_fac,'LineColor', 'none');
[C1,h1] = contour(TT,SS,(phi_CW83-phi)*unit_fac,diff_levels*unit_fac,'LineColor', 'k');
clabel(C1, h1)%, 'LabelSpacing', 200)%,'FontSize',8);
%colorbar
xlabel('T (C)')
ylabel('S (g/kg)')
set(gca,'yscale','log')
set(gca,'fontsize', fs)
set(gca, 'FontName', 'Helvetica LT Std')
xlim([-36 0.])
ylim([0. 40.])
yticks([1. 5. 10. 20. 40.])
xticks([-36 -30. -20. -10. 0.])

plot([-2 -2], [0.3 40], 'k--')
plot([-30 -30], [0.3 40], 'k--')