
; this small script generates molar (mol/kg) and mass concentrations in standard seawater (Millero et al, 2008)

;SA = 35.165040D             ; input absolute salinity
;SA = 15.000000D             ; input absolute salinity
SA =  1.00000D               ; input absolute salinity

OPENR, 10, 'SA.txt'
READF, 10, SA
PRINT, ' SA = ', SA, ' g/kg '
CLOSE, 10

Sp = SA * 35.D / 35.16504D  ; convert into practical salinity (TEOS-10, section 2.4)

Cl = SA / 1.80655D          ; chlorinity as per Millero et al 2008 (eq 2.4, p. 57)

N_ions = 15

; ion names
c_ion = [ 'Na+'    , 'Mg2+' , 'Ca2+' , 'K+'    , 'Sr2+' , $
          'Cl-'    , 'SO42-', 'HCO3-', 'Br-'   , 'CO32-', $
          'B(OH4)-', 'F-'   , 'OH-'  , 'B(OH)3', 'CO2'      ]

; mass ratios to chlorinity in standard seawater (Table 4)
r_ion = [ 0.5564924D, 0.0662600D, 0.0212700D, 0.0206000D, 0.0004100D, $
          0.9989041D, 0.1400000D, 0.0054100D, 0.0034730D, 0.0007400D, $
          0.0004100D, 0.0000670D, 0.0000070D, 0.0010030D, 0.0000220D ]

; molar concentrations (mol/kg)
A_ion = DBLARR(N_ions)

molecular_mass, 'Na',   zarr & A_ion(0) = zarr
molecular_mass, 'Mg',   zarr & A_ion(1) = zarr
molecular_mass, 'Ca',   zarr & A_ion(2) = zarr
molecular_mass, 'K' ,   zarr & A_ion(3) = zarr
molecular_mass, 'Sr',   zarr & A_ion(4) = zarr
molecular_mass, 'Cl',   zarr & A_ion(5) = zarr
molecular_mass, 'SO4',  zarr & A_ion(6) = zarr 
molecular_mass, 'HCO3', zarr & A_ion(7) = zarr
molecular_mass, 'Br'  , zarr & A_ion(8) = zarr
molecular_mass, 'CO3',  zarr & A_ion(9) = zarr
molecular_mass, 'BOH4', zarr & A_ion(10) = zarr
molecular_mass, 'F',    zarr & A_ion(11) = zarr
molecular_mass, 'OH',   zarr & A_ion(12) = zarr
molecular_mass, 'BOH3', zarr & A_ion(13) = zarr
molecular_mass, 'CO2',  zarr & A_ion(14) = zarr

; mass fraction (g per kg of solution, w_i) - has to be multiplied by chlorinity
Cmass = r_ion * Cl * 1.80655 / total(r_ion)

; molar concentrations (mol per kg of solution, xi)
Cmol = Cmass / A_ion

; molal concentrations (mol per kg of H2O) - FREZCHEM WANTS MOLAL CONCENTRATIONS !!!!
Cmol = Cmol * ( 1 + SA/1000. )

; check backwards computation of salinity
;zS_test= sum( Cmass )

STOP

;==============================================================================
; Export into FREZCHEM readable file
;==============================================================================
;c_ss = STRCOMPRESS(STRING(SA,FORMAT='(F5.2)'), /REMOVE_ALL)

c_ss = STRCOMPRESS(STRING(SA,FORMAT='(I2)'), /REMOVE_ALL)
IF ( FLOAT(SA) LT 10. ) THEN c_ss = '0'+c_ss

file_name = 'Input_S'+c_ss+'.txt'
print, ' Create FREZCHEM file : ', file_name
OPENW, 10, file_name

;--- First 5 lines
PRINTF, 10, 'TITLE: '+' standard seawater at SA = '+c_ss+' g/kg'
PRINTF, 10, '1, FREEZE(1) OR EVAPORATION(2) OR PRESSURE(3) SCENARIO ? CALLED PATH BELOW.'
PRINTF, 10, '1, EQUILIBRIUM(1) OR FRACTIONAL(2) CRYSTALLIZATION?'
PRINTF, 10, '1, OPEN(1) OR CLOSED(2) CARBON SYSTEM?'
PRINTF, 10, '0, WANT SEAWATER SALINITY(Sp) TO GOVERN THE CALCULATIONS,Y=1,N=0.'

; --- SP Practical salinity
;40.0, IF YES ABOVE, ENTER SEAWATER PRACTICAL SALINITY(Sp) OR 0.0.
c_write = c_ss+', IF YES ABOVE, ENTER SEAWATER PRACTICAL SALINITY(Sp) OR 0.0.'
PRINTF, 10, c_write
print, c_write

; --- Follow-up
PRINTF, 10, '1, WANT SEAWATER CARBONATE SUPERSATURATION TO BE CONSIDERED? Y=1,N=0'

; --- Na
; 0.48606, SODIUM(M/KG).
c_Cmol = STRCOMPRESS(STRING(Cmol(0),FORMAT='(F12.10)'), /REMOVE_ALL)
c_write = c_Cmol+', SODIUM(M/KG).'
PRINTF, 10, c_write
print, c_write, ' '+c_ion(0)

; --- K
; 0.01058, POTASSIUM(M/KG).
c_Cmol = STRCOMPRESS(STRING(Cmol(3),FORMAT='(F12.10)'), /REMOVE_ALL)
c_write = c_Cmol+', POTASSIUM(M/KG).'
PRINTF, 10, c_write
print, c_write, ' '+c_ion(3)

; --- Ca
; 0.01066, CALCIUM(M/KG).
c_Cmol = STRCOMPRESS(STRING(Cmol(2),FORMAT='(F12.10)'), /REMOVE_ALL)
c_write = c_Cmol+', CALCIUM(M/KG).'
PRINTF, 10, c_write
print, c_write, ' '+c_ion(2)

; --- Mg
; 0.05474, MAGNESIUM(M/KG).
c_Cmol = STRCOMPRESS(STRING(Cmol(1),FORMAT='(F12.10)'), /REMOVE_ALL)
c_write = c_Cmol+', MAGNESIUM(M/KG).'
PRINTF, 10, c_write
print, c_write, ' '+c_ion(1)

; --- Sr
; 0.00009, STRONTIUM(M/KG).
c_Cmol = STRCOMPRESS(STRING(Cmol(4),FORMAT='(F12.10)'), /REMOVE_ALL)
c_write = c_Cmol+', STRONTIUM(M/KG).'
PRINTF, 10, c_write
print, c_write, ' '+c_ion(4)

; --- Follow-up
PRINTF, 10, '0.00, FERROUS IRON(M/KG).'
PRINTF, 10, '0.00, FERRIC IRON (M/KG).'
PRINTF, 10, '0.00, ALUMINUM(M/KG).'
PRINTF, 10, '0.00, SILICA (M/KG).'
PRINTF, 10, ''
PRINTF, 10, 'FOR FE,AL,SI, AND ALKALINE CHEMISTRIES,DO YOU WANT ACIDITY'
PRINTF, 10, 'IGNORED(1),OR FIXED BY PH(2), OR ACIDITY(3), OR'
PRINTF, 10, 'ALKALINITY(4)? IF YES, THEN ENTER NUM. NOTE THAT OPTIONS 3'
PRINTF, 10, 'AND 4 REQUIRE A FURTHER SPECIFICATION BELOW. OPTIONS 2-4'
PRINTF, 10, 'WILL ADJUST SOLUTION-PHASE CHARGE BALANCE AS AL, FE, OR SI'
PRINTF, 10, 'REACTIONS PRODUCE ACIDITY BY ASSUMING H+ REACTS WITH ROCKS'
PRINTF, 10, 'TO RELEASE NA,K,CA,MG,OR FE(II) IONS. SOME OF THE LATTER'
PRINTF, 10, 'IONS MUST BE PRESENT AS INPUT TO SERVE AS AN ION SINK/SOURCE.'
PRINTF, 10, ''
PRINTF, 10, '4, SPECIFY ABOVE ACIDITY OPTION.'

; --- pH
; 8.00, SPECIFY INITIAL PH.
c_Cmol = STRCOMPRESS(STRING(8.10,FORMAT='(F4.2)'), /REMOVE_ALL)
c_write = c_Cmol+', SPECIFY INITIAL PH.'
PRINTF, 10, c_write
print, c_write, ' '+' pH'

; --- Cl
; 0.56576, CHLORIDE(M/KG).
c_Cmol = STRCOMPRESS(STRING(Cmol(5),FORMAT='(F12.10)'), /REMOVE_ALL)
c_write = c_Cmol+', CHLORIDE(M/KG).'
PRINTF, 10, c_write
print, c_write, ' '+c_ion(5)

; --- Br
; 0.00087, BROMIDE(M/KG).
c_Cmol = STRCOMPRESS(STRING(Cmol(8),FORMAT='(F12.10)'), /REMOVE_ALL)
c_write = c_Cmol+', BROMIDE(M/KG).'
PRINTF, 10, c_write
print, c_write, ' '+c_ion(8)

;--- Follow-up
PRINTF, 10, '0.00, PERCHLORATE(M/KG).'

; --- SO4
; 0.02926, SULFATE(M/KG).
c_Cmol = STRCOMPRESS(STRING(Cmol(6),FORMAT='(F12.10)'), /REMOVE_ALL)
c_write = c_Cmol+', SULFATE(M/KG).'
PRINTF, 10, c_write
print, c_write, ' '+c_ion(6)

;--- Follow-up
PRINTF, 10, '0.00, NITRATE(M/KG).'

; --- Alk
; 0.00240, ALKALINITY(EQUIVALENTS/KG).
c_Cmol = STRCOMPRESS(STRING(0.00230,FORMAT='(F12.10)'), /REMOVE_ALL)
c_write = c_Cmol+', ALKALINITY(EQUIVALENTS/KG).'
PRINTF, 10, c_write
print, c_write, ' Alk '

; --- Follow up
PRINTF, 10, '0.00, ACIDITY(EQUIVALENTS/KG).'
PRINTF, 10, '0.00, IF YOU WANT TO SPECIFY HCL(BARS), ENTER VALUE HERE.'
PRINTF, 10, '0.00, IF YOU WANT TO SPECIFY HNO3(BARS), ENTER VALUE HERE.'
PRINTF, 10, '0.00, IF YOU WANT TO SPECIFY H2SO4(BARS), ENTER VALUE HERE.'

; --- Total B
; 0.00043, BORON (M/KG).
c_Cmol = STRCOMPRESS(STRING(Cmol(10)+Cmol(13),FORMAT='(F12.10)'), /REMOVE_ALL)
c_write = c_Cmol+', BORON (M/KG).'
PRINTF, 10, c_write
print, c_write, ' B   '

; --- F
; 0.00007, FLUORIDE(M/KG).
c_Cmol = STRCOMPRESS(STRING(Cmol(11),FORMAT='(F12.10)'), /REMOVE_ALL)
c_write = c_Cmol+', FLUORIDE(M/KG).'
PRINTF, 10, c_write
print, c_write, ' F   '

PRINTF, 10., '1.01325, INITIAL TOTAL PRESSURE(BARS).'
PRINTF, 10., '3.85E-4, INITIAL CO2(BARS).'
PRINTF, 10., '0.0, ENTER MOLE FRACTION OF CO2, 0=FIXED CO2, 1=PURE CO2.'
PRINTF, 10., '0.00, INITIAL O2(BARS).'
PRINTF, 10., '0.00, INITIAL CH4(BARS).'
PRINTF, 10., '0.00, ENTER MOLE FRACTION OF CH4, 0=FIXED CHR, 1=PURE CH4.'
PRINTF, 10., '0, CONSIDER A MIXED CO2-CH4 GAS HYDRATE(YES=1, NO=0)?'
PRINTF, 10., '0, MOLAR TO MOLAL CONVERSION? YES=1,NO=0.'
PRINTF, 10., '0.0, IF YES ABOVE, ENTER SALINITY(G)/LITER.'
PRINTF, 10., '273.15, INITIAL TEMPERATURE(K).'
PRINTF, 10., '231.15, FINAL TEMPERATURE(K), IF PATH =1, OTHERWISE, SET = 0.'
PRINTF, 10., '0.10, TEMPERATURE DECREMENT(K), IF PATH = 1, OTHERWISE, SET = 0.'
PRINTF, 10., '1000, INITIAL WATER(G), IF PATH = 2, OTHERWISE, SET = 1000.'
PRINTF, 10., '0, FINAL WATER (G), IF PATH = 2, OTHERWISE, SET = 0.'
PRINTF, 10., '0, WATER DECREMENT(K), IF PATH = 2, OTHERWISE, SET = 0.'
PRINTF, 10., '0, FINAL PRESSURE(BARS), IF PATH = 3, OTHERWISE, SET = 0.'
PRINTF, 10., '0, PRESSURE INCREMENT(BARS), IF PATH = 3, OTHERWISE, SET = 0.'

CLOSE, 10

END
