function [S_liq] = S_liquidus(T,i_opt)
%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
%=========================================================================================================
%
% S_liquidus : computes brine salinity for different thermodynamic formulations
%
% IN
%
% T                : Ice Temperature (C)
% i_opt            : 1=Assur 58; 2=Notz Worster 2009; 3=3rd POLY3 fit; 
%                    4=TEOS-10 extended; 5=TEOS-10 modified; 6=Cox Weeks 86; 
%                    7=FREZCHEM
%
% OUT
%
% S_liq            : Liquidus salinity (g/kg)
%
%
% Made in France by the beloved Martin Vancoppenolle (Aug 2017, Lille)
%
%=========================================================================================================

if ( i_opt == 1 ); % Assur, 1958
   S_liq = - T / 0.05411;
end

if ( i_opt == 2 ); % Notz and Worster, 2009
   zT2 =   T .* T;
   zT3 = zT2 .* T;
   S_liq = - ( 21.4*T + 0.886*zT2 + 0.0170 * zT3 );
end

if ( i_opt == 3 ); % POLY3 Fit
    zT2 =   T .* T;
    zT3 = zT2 .* T;
    S_liq = - ( 0.00535 * zT3 + 0.519 * zT2 + 18.7 * T );
end;

if ( i_opt == 4 | i_opt == 5 ); % TEOS-10 expanded, TEOS-10 modified (reciprocal of freezing point)

    % Iterative procedure to retrieve liquidus directly from freezing point
    % makes it very expensive!!!
    Nit = 8; % 5 makes it converge until 1.0e-14
    
    S0 = T ./ -0.05411 / 2.;
    for i = 1:Nit
       T0     = T_freeze(S0,i_opt);
       dT_dS0 = T_freeze_deriv_S(S0,i_opt);
       S1     = S0 + ( T - T0 ) ./ dT_dS0;
       S0     = S1;
    end
    S_liq = S1;
    
end;

if ( i_opt == 6 ); % Cox & Weeks, Journal of Glaciology, 1986, Table I
    
   zT2 =   T .* T;
   zT3 = zT2 .* T;
   
   S_liq = T; S_liq(:) = nan;
   
   zaddr = find( T<= -2. & T > -22.9 ); 
   S_liq(zaddr)   = -3.9921 - 22.700*T(zaddr) - 1.0015*zT2(zaddr) -0.019956*zT3(zaddr);
   clear zaddr
   
   zaddr = find( ( T <= -22.9 ) & ( T > -44.0 ) ); 
   S_liq(zaddr)   = 206.24 - 1.8907*T(zaddr) - 0.060868*zT2(zaddr) -0.0010247*zT3(zaddr);
   clear zaddr
   
   zaddr = find( ( T <= -44.0 ) );
   S_liq(zaddr)   = -4442.1 - 277.86*T(zaddr) - 5.501*zT2(zaddr) - -0.03669*zT3(zaddr);
   clear zaddr
   
end

if ( i_opt == 7 ); % FREZCHEM
    
   % read frezchem
   fc          = read_frezchem;
   T_fc        = fc.T;
   S_liq_fc    = fc.S_br';
   
   i_sal       = 1; % f_ss is independent of salinity so we don't care

   S_liq       = pchip(T_fc,S_liq_fc(:,i_sal),T); % Piecewise cubic hermite interpolating polynomial
   
   S_liq(find(T>=0.)) = 0.;
   
   % values with T higher than Tfr(0.3 g/kg) must be reinterpolated because
   % we have no data (frezchem crashes)
   % such T is around 0.01 C
   % for safety we assume that T = -0.05 is the threshold from which reinterpolation must occur
   zaddr = find(T>=-0.05 & T<-1.e-5);
   zsize = size(zaddr);
   
   if ( zsize(2) > 0  );

      zT0  = -0.05;
      zS0 = 1.087337977456068; % S_frezchem (-0.05C)
         
      zm = zS0 ./ zT0;
      S_liq(zaddr) = zS0 + zm .* ( T(zaddr) - zT0 ); % re-interpolate data properly
      
   end;
   
end