function [dSliq_dT] = S_liquidus_deriv_T(T,i_opt)
%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
%=========================================================================================================
%
% S_liquidus : computes brine salinity derivative for different thermodynamic formulations
%
% IN
%
% T                : Ice Temperature (C)
% i_opt            : 1=Assur 58; 2=Notz Worster 2009; 3=3rd order fit; 
%                    4=TEOS-10 extended; 5=TEOS-10 modified; 6=Cox Weeks 86
%
% OUT
%
% dSliq_dT         : Brine salinity derivative wrt T (g/kg/C)
%
%--------------------------------------------------------------------------------------------------------
%
% Made in France by the beloved Martin Vancoppenolle (Aug 2017, Lille)
%
%=========================================================================================================

if ( i_opt == 1 ); % Bitz and Lipscomb, 1999
    
   dSliq_dT      = T;
   dSliq_dT(:,:) = - 1. / 0.05411;
   
end

if ( i_opt == 2 ); % Notz and Worster 2009
    
   zT2          =   T .* T;
   dSliq_dT      = - ( 21.4 + 2.*0.886*T + 3. * 0.0170 * zT2 );
   
end

if ( i_opt == 3 ); % 3rd order fit on all available data

    zT2         =   T .* T;
    dSliq_dT     = - ( 18.7 + 2.*0.519*T + 3. * 0.00535 * zT2 );

end;

if ( i_opt == 4 | i_opt == 5 | i_opt == 6 | i_opt == 7 ); % eTEOS-10, mTEOS-10, CW86, Frezchem
    
    dT          = 1.0e-6; % chosen empirically
    dSliq_dT     = ( S_liquidus(T,i_opt) - S_liquidus(T-dT,i_opt) ) / dT;

end;
