clear all; close all

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
% TAB5
%
%=========================================================================================================

T_eutectic = -36.2;

unit_fac   = 1000.; % 1000 for g/kg, 100 for %

if (unit_fac == 1000); c_unit = 'g/kg'; elseif ( unit_fac == 100. ); c_unit = '%'; end

%---------------------------------------------------------------------------------------------------------
%
% Load RK66 data
%
%---------------------------------------------------------------------------------------------------------

% Load RK66 NMR retrievals
[ S_RK66_exp1, T_RK66_exp1, phi_H2O_br_RK66_exp1, ...
  S_RK66_exp2, T_RK66_exp2, phi_H2O_br_RK66_exp2] = phi_H2O_br_obs;

% Assemble arrays
T = [ T_RK66_exp1 T_RK66_exp2 ];
zs1 = T_RK66_exp1; zs1(:) = S_RK66_exp1;
zs2 = T_RK66_exp2; zs2(:) = S_RK66_exp2;
S = [ zs1 zs2 ];

phi_H2O_liq_RK66_raw = [ phi_H2O_br_RK66_exp1 phi_H2O_br_RK66_exp2 ] / 1000.;

zaddr       = find( T >= T_eutectic);
zaddr_exp1  = find( T >= T_eutectic & S == S_RK66_exp1 );
zaddr_exp2  = find( T >= T_eutectic & S == S_RK66_exp2 );

zs = size(T); N_RK66 = zs(2);

%---------------------------------------------------------------------------------------------------------
%
% Liquid H2O mass fraction retrievals
%
%---------------------------------------------------------------------------------------------------------

% FREZCHEM, raw
fc = read_frezchem;
T_fc = fc.T;
S_fc = fc.SA;
phi_H2O_liq_fc_raw  = fc.phi_H2O_liq;

% FREZCHEM, calculated
phi_H2O_liq_fc = zeros(N_RK66);
phi_H2O_liq_fc(zaddr_exp1) = pchip(T_fc,phi_H2O_liq_fc_raw(36,:),T(zaddr_exp1)) * S_RK66_exp1 / 35.;
phi_H2O_liq_fc(zaddr_exp2) = pchip(T_fc,phi_H2O_liq_fc_raw(11,:),T(zaddr_exp2)) * S_RK66_exp2 / 10.;

% BL99, no minerals
Sbr_BL99         = S_liquidus(T,1);
phi_liq_BL99     = phi_br(S, T, 1, 0, 0, T_eutectic);
phi_H2O_liq_BL99 = phi_liq_BL99 .* ( 1. - Sbr_BL99 / 1000. );

% NW09, no minerals
Sbr_NW09         = S_liquidus(T,2);
phi_liq_NW09     = phi_br(S, T, 2, 0, 0, T_eutectic);
phi_H2O_liq_NW09 = phi_liq_NW09 .* ( 1. - Sbr_NW09 / 1000. );

% POLY3, no minerals
Sbr_3o          = S_liquidus(T,3);
phi_liq_3o     = phi_br(S, T, 3, 0, 0, T_eutectic);
phi_H2O_liq_3o = phi_liq_3o .* ( 1. - Sbr_3o / 1000. );

% POLY3 + FREZCHEM minerals
Sbr_3o_ss         = S_liquidus(T,3);
phi_liq_3o_ss     = phi_br(S, T, 3, 2, 0, T_eutectic);
phi_H2O_liq_3o_ss = phi_liq_3o_ss .* ( 1. - Sbr_3o_ss / 1000. );

% mTEOS-10 + FREZCHEM minerals
Sbr_TEOS10_ss         = S_liquidus(T,5);
phi_liq_TEOS10_ss     = phi_br(S, T, 5, 2, 0, T_eutectic);
phi_H2O_liq_TEOS10_ss = phi_liq_TEOS10_ss .* ( 1. - Sbr_TEOS10_ss / 1000. );

% FREZCHEM liquidus, minerals
Sbr_fc2_ss            = S_liquidus(T,7);
phi_liq_fc2_ss        = phi_br(S, T, 7, 2, 0, T_eutectic);
phi_H2O_liq_fc2_ss    = phi_liq_fc2_ss .* ( 1. - Sbr_fc2_ss / 1000. );

% CW
Sbr_CW                = S_liquidus(T,6);
phi_liq_CW            = phi_br(S, T, 6, 0, 0, T_eutectic);
phi_H2O_liq_CW        = phi_liq_CW .* ( 1. - Sbr_CW / 1000. );

%---------------------------------------------------------------------------------------------------------
%
% Print differences
%
%---------------------------------------------------------------------------------------------------------

disp({'==============================================================='})
disp({' *** Differences wrt RK66 liquid mass fraction (N=23)      *** '})
disp({'==============================================================='})

%zaddr       = find( T >= T_eutectic & T <=-2.);
zaddr = find( ~isnan(phi_H2O_liq_CW) ); % for a fair comparison, we do it where the CW value is defined

disp({' * FREZCHEM raw calculation '})
zdiff     = phi_H2O_liq_fc(zaddr) - phi_H2O_liq_RK66_raw(zaddr);
disp({' Mean Bias : ', mean2(zdiff)*unit_fac, c_unit}  )
disp({' RMSE      : ', mean2( sqrt( (zdiff).^2 ) ) * unit_fac, c_unit} )
disp({' STDE      : ', std2(zdiff)* unit_fac, c_unit} )

disp({' * FREZCHEM liquidus & minerals '})
zdiff     = phi_H2O_liq_fc2_ss(zaddr) - phi_H2O_liq_RK66_raw(zaddr);
disp({' Mean Bias : ', mean2(zdiff)*unit_fac, c_unit}  )
disp({' RMSE      : ', mean2( sqrt( (zdiff).^2 ) ) * unit_fac, c_unit} )
disp({' STDE      : ', std2(zdiff)* unit_fac, c_unit} )

disp({' * Linear liquidus, no minerals '})
zdiff     = phi_H2O_liq_BL99(zaddr) - phi_H2O_liq_RK66_raw(zaddr);
disp({' Mean Bias : ', mean2(zdiff)*unit_fac, c_unit}  )
disp({' RMSE      : ', mean2( sqrt( (zdiff).^2 ) ) * unit_fac, c_unit} )
disp({' STDE      : ', std2(zdiff)* unit_fac, c_unit} )

disp({' * NW09 liquidus, no minerals '})
zdiff     = phi_H2O_liq_NW09(zaddr) - phi_H2O_liq_RK66_raw(zaddr);
disp({' Mean Bias : ', mean2(zdiff)*unit_fac, c_unit}  )
disp({' RMSE      : ', mean2( sqrt( (zdiff).^2 ) ) * unit_fac, c_unit} )
disp({' STDE      : ', std2(zdiff)* unit_fac, c_unit} )

disp({' *POLY3 liquidus, no minerals '})
zdiff     = phi_H2O_liq_3o(zaddr) - phi_H2O_liq_RK66_raw(zaddr);
disp({' Mean Bias : ', mean2(zdiff)*unit_fac, c_unit}  )
disp({' RMSE      : ', mean2( sqrt( (zdiff).^2 ) ) * unit_fac, c_unit} )
disp({' STDE      : ', std2(zdiff)* unit_fac, c_unit} )

disp({' * CW '})
zdiff     = phi_H2O_liq_CW(zaddr) - phi_H2O_liq_RK66_raw(zaddr);
disp({' Mean Bias : ', mean2(zdiff)*unit_fac, c_unit}  )
disp({' RMSE      : ', mean2( sqrt( (zdiff).^2 ) ) * unit_fac, c_unit} )
disp({' STDE      : ', std2(zdiff)* unit_fac, c_unit} )

disp({' * 3-o. liquidus, minerals '})
zdiff     = phi_H2O_liq_3o_ss(zaddr) - phi_H2O_liq_RK66_raw(zaddr);
disp({' Mean Bias : ', mean2(zdiff)*unit_fac, c_unit}  )
disp({' RMSE      : ', mean2( sqrt( (zdiff).^2 ) ) * unit_fac, c_unit} )
disp({' STDE      : ', std2(zdiff)* unit_fac, c_unit} )

disp({' * mTEOS-10 liquidus, minerals '})
zdiff     = phi_H2O_liq_TEOS10_ss(zaddr) - phi_H2O_liq_RK66_raw(zaddr);
disp({' Mean Bias : ', mean2(zdiff)*unit_fac, c_unit}  )
disp({' RMSE      : ', mean2( sqrt( (zdiff).^2 ) ) * unit_fac, c_unit} )
disp({' STDE      : ', std2(zdiff)* unit_fac, c_unit} )