function [T_freeze] = T_freeze(S,i_opt)
%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
%=========================================================================================================
%
% T_freeze : gets the freezing point as a function of salinity (reciprocal of the liquidus)
%
% IN
%
% S                : Absolute Salinity (g/kg)
% i_opt            : 1=Assur 58; 2=Notz Worster 2009; 3=3rd order fit; 
%                    4=TEOS-10 extended; 5=TEOS-10 modified; 6=Cox Weeks 86;
%                    7=FREZCHEM
%
% OUT
%
% T_freeze         : Freezing point in C
%
%--------------------------------------------------------------------------------------------------------
%
% Made in France by the beloved Martin Vancoppenolle (Aug 2017, Lille)
%
%=========================================================================================================

%---------------------------
% Linear fit - Assur (1958)
%---------------------------
if ( i_opt == 1 ); % Assur 58
   T_freeze = - 0.05411 * S;
end

%-----------------------------
% NW09, POLY3, CW86, FREZCHEM
%-----------------------------
% Best option to invert a polynom is an iterative numerical inversion

if ( i_opt == 2 | i_opt == 3 | i_opt == 6 | i_opt == 7);
    
   Nit   = 7;
   T0    = S;
   T0(:,:)    = -1.0e-18;
   
   for i = 1:Nit
       S0     = S_liquidus(T0,i_opt);
       dS_dT0 = S_liquidus_deriv_T(T0,i_opt);
       T1     = T0 + ( S - S0 ) ./ dS_dT0;
       T0     = T1;
   end
   
   T_freeze = T1(:,:);
  
end

%------------------
% Expanded TEOS-10
%------------------
if ( i_opt == 4 ); % TEOS-10 expanded
    
    T_freeze = gsw_t_freezing_extended(S,0.,0.);
     
end

%------------------
% Modified TEOS-10
%------------------
if ( i_opt == 5 ); % TEOS-10 modified
    
    T_freeze = gsw_t_freezing_modified(S,0.,0.,'S', 1); 
     
end
    
end
   