
function [ Sliq_obs, T_obs, S_G37, T_G37, S_B16, T_B16, S_NT54, T_NT54, S_DK74, T_DK74 ] = ...
         liquidus_obs(T_eutectic)

%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%   
%=========================================================================================================
% 
% liquidus_obs:
% - put all retained iquidus observations together
% - gather, sort and exclude data points below the assumed eutectic
%
% IN 
%    * T_eutectic, the eutectic temperature (C)
%
% OUT
%    * Sliq_obs, T_obs: sorted liquidus salinity (g/kg) and temperature (C)
%    * S_G37, T_G37, S_B16, T_B16, S_NT54, T_NT54, S_DK74, T_DK74:
%         liquidus salinity and temperature from individual observational sources
%
% Observational sources:
%
% Gitterman, K. (1937), Thermitcheskii analis morskoi vody (Thermal analysis of sea water), 
% Tech. rep., Trudy Solyanoy Laboratorii (SSSR), translation from 1971, 
% USA Cold Regions Research and Engineering Laboratory, Hanover, NH. CRREL- TL-287.
%
% Nelson, K., and T. Thompson (1954), Deposition of salts from sea water by frigid concentration, 
% J. Mar. Res, 13, 166?182.
%
% Doherty, B. T., and D. Kester (1974), Freezing point of seawater, 
% Journal of Marine Research, 32, 285?300.
%
% Butler, B., S. Papadimitriou, and H. Kennedy (2016b), 
% The effect of mirabilite precipitation on the absolute and practical salinities of sea ice brines, Marine Chemistry, 184, 21? 31, 10.1016/j.marchem.2016.06.003.
%
% ---
% 
% Correction of Doherty and Kester 1974 following Feistel (1998)
%
% Feistel, R. (2008), A Gibbs function for seawater thermodynamics for ?6 to 80C
% and salinity up to 120 g kg?1, Deep Sea Research (I), 55, 1639?1671.
%
% (c) beloved Martin Vancoppenolle, trains, 2018.
%

%
%---------------------------------------------------------------------------------------------------------
% Observations;
%---------------------------------------------------------------------------------------------------------
%
%-------------------
% 1) Gitterman 1937 
%-------------------
% Table 7 Page 15
%
T_G37 = [ -1.8 -5.6 -7.6 -9.5 -10.6 ...
      -12.3 -15.0 -17.0 -22.6 -24.2 ...
      -26.0 -28.0 -30.8 -32.2 -34.2 ...
      -35.5 ] / 1.00024; % conversion from ITP38 to ITP90 temperature
  
S_G37 = [ 32.8 92.4 119.4 133.4 146.7 ...
      155.1 175.5 188.8 230.4 227.5 ...
      227.5 233.6 239.5 241.8 245.0 ...
      248.4 ];

%-------------------------------
% 2) Nelson and Thompson (1954)
%-------------------------------
% Table 1, p. 10
% Retained only where there is SO4 concentration available
T_NT54 = [ -4.4000   -6.9000   -8.6000  -10.6000  -13.1000  -16.2500  -20.6000  -26.4000  -29.9500 ]  / 1.00024; % conversion from ITP38 to ITP90 temperature
S_NT54 = [ 70.8400  103.1100  121.9200  141.1200  160.7400  183.9400  212.9900  231.6800  237.7900 ]; 

%-------------------------
% 3) Butler et al. (2016)
%-------------------------
% data communicated privately
T_B16 = [ -1.8 -2.9 -3.9 -5 -6 -6.2 -7 -7.9 -8.9 -10.1 -11.1 -11.8 -12.8 -14 -15.1 -15.9 -17.5 -20.6 ];
S_B16 = [ 35.19 52.96 70.37 85. 99.68 100.17 111.05 120.61 131.57 140.55 148.28 156.89 165.22 172.32 180.67 187.82 200.24 218.73];
         
%------------------------------
% 4) Doherty and Kester (1974)
%------------------------------
% data from Tables II (p. 292) and III (p. 294)
S_DK74 = [ 36.5200   35.4900   34.5000   33.0000   30.0000   27.0100   22.0100   16.9900   11.9700    6.9700   40.2000 ...
                      39.7500   36.9600   36.1800   35.0600   34.9000   34.4200   32.1400   31.6500   30.2200   28.1500 ];

T_DK74_raw = [ -2.010 -1.950 -1.894 -1.808 -1.637 -1.471 -1.195 -0.920 -0.649 -0.381 ...
                          -2.220 -2.197 -2.032 -1.990 -1.925 -1.916 -1.888 -1.758 -1.731 -1.652 -1.535 ];
                  
% apply the conversions proposed by Feistel (2008), eq. 6.29
zT2a = T_DK74_raw - S_DK74/70.000*1.000e-3;
zT2b = zT2a / 1.00024000;  % convert from IPTS-68 top ITS-90
zT2c = 2.519000e-3 + zT2b; % add the 2.519 mK

T_DK74 = [ zT2c ];

%---------------------------------------------------------------------------------------------------------
% Gather, sort, exluding points below eutectic
%---------------------------------------------------------------------------------------------------------

% gather observations
S_obs = [ S_G37 S_NT54 S_DK74 S_B16 ];
T_obs = [ T_G37 T_NT54 T_DK74 T_B16 ];

% sort temperatures
[ T_obs, zaddr ] = sort(T_obs);
S_obs = S_obs(zaddr);

% exclude points below T_eutectic
zaddr = find( T_obs >= T_eutectic );
T_obs = T_obs(zaddr);
Sliq_obs = S_obs(zaddr);

size(zaddr);

end