function [phi] = phi_br(S,T,i_liq,i_ss,i_vf,T_eutectic)
%=========================================================================================================
%
% Thermodynamics of sea ice phase composition revisited
% Martin Vancoppenolle, Gurvan Madec, Max Thomas, Trevor McDougall
% JGR, 2018
%
% Supporting material
%
% Made on Earth with love in 2017-2018, 
% between Austria, Belgium, France, Russia & Switzerland
%
%=========================================================================================================
%
% phi_icethermo : computes brine mass fractions for different thermodynamic formulations
%
% IN
%
% S                : Ice Salinity (g/kg)
% T                : Ice Temperature (C)
% i_opt            : 1=Assur 58; 2=Notz Worster 2009; 3=3rd order fit; 
%                    4=TEOS-10 extended; 5=TEOS-10 modified; 6=Cox Weeks 83
% i_ss             : Solid salt option - 1 Assur58, 2- FREZCHEM piecewise interpolated
% i_vf             : 0 if conversion into brine volume fraction is desired
% T_eutectic       : Eutectic temperature (C)
%
% OUT
%
% phi              : Brine mass fraction (.)
%
%--------------------------------------------------------------------------------------------------------
%
% Made in France by the beloved Martin Vancoppenolle (Aug 2017, Lille)
%
%=========================================================================================================

if ( i_liq ~= 6 ) ; % all but CW83 relationships
    
    Sbr     = S_liquidus(T,i_liq);  % brine salinity
    
    f_min   = fs_minerals(T,i_ss,T_eutectic);  % mineral salt fraction
%     
    if ( i_ss == 0 );
        zswitch = 0;
    end
     
    if ( i_ss >= 1 );
        zswitch = 1;
    end
     
    phi     = S .* ( 1.000000 - zswitch * f_min ) ./ Sbr;
    
    phi(phi>1) = 1.;

end

if ( i_liq == 6 ); % Cox and Weeks 83
    
    zT2   = T   .* T;
    zT3   = zT2 .* T;
    
    % create zero arrays of the good size
    alpha_01 = T - T;    alpha_01(:) = NaN; 
                         alpha_11 = alpha_01; alpha_21 = alpha_01; alpha_31 = alpha_01;
    alpha_02 = alpha_01; alpha_12 = alpha_01; alpha_22 = alpha_01; alpha_32 = alpha_01;
    
    % coeffs for F1(T)
    zaddr = find( T <= -2. & T>=-22.9 );
    alpha_01(zaddr) = -4.732;
    alpha_11(zaddr) = -2.245e1;
    alpha_21(zaddr) = -6.397e-1;
    alpha_31(zaddr) = -1.074e-2;
    
    zaddr = find( T<-22.9 & T>= -30. );
    alpha_01(zaddr) = 9.899e3;
    alpha_11(zaddr) = 1.309e3;
    alpha_21(zaddr) = 5.527e1;
    alpha_31(zaddr) = 7.160e-1;
    
    % coeffs for F2(T)
    zaddr = find( T <= -2. & T>=-22.9 );
    alpha_02(zaddr) = 8.903e-2;
    alpha_12(zaddr) = -1.763e-2;
    alpha_22(zaddr) = -5.330e-4;
    alpha_32(zaddr) = -8.801e-6;
    
    zaddr = find( T<-22.9 & T>= -30. );
    alpha_02(zaddr) = 8.547;
    alpha_12(zaddr) = 1.089;
    alpha_22(zaddr) = 4.518e-2;
    alpha_32(zaddr) = 5.819e-4;

    % F1 and F2
    zf1   = alpha_01 + alpha_11 .* T + alpha_21 .* zT2 + alpha_31 .* zT3;
    zf2   = alpha_02 + alpha_12 .* T + alpha_22 .* zT2 + alpha_32 .* zT3;
    
    % brine density
    rhobr  = 1000 + 0.8*S;
    
    % ice density
    rhoi = 917.0 - 0.1403 * T;
    
    % Neglect air volume
    znum = rhoi / 1000. .* S;
    zden = zf1 - rhoi / 1000. .* S .* zf2;
    
    % brine volume fraction
    zbv  = znum ./ zden;
    
    % brine mass fraction (Notz Phd, 2005; page 44)
    zr   = rhoi ./ rhobr;
    whos zr
    whos zbv
    phi  = 1. ./ ( 1 + ( 1. ./ zbv - 1) .* zr );
end

phi(T==0.) = 1.; % ensure phi = 1 at 273.15 K (not guaranteed because Sbr = 0)

%------------------------------------------------------------------------------
% Conversion in to brine volume fraction (i_vf = 1)
%------------------------------------------------------------------------------

if ( i_vf == 1 ); % Notz Phd, 2005; page 44
    
    rhoi    =   917.0 - 0.1403 * T; % Pounder (update into TEOS-10 maybe)
    rhobr   =   1000 + 0.8*S;       % CW83    (update into TEOS-10)
    zr      =   rhobr ./ rhoi;

    zden    =   1. + ( 1. ./ phi - 1 ) .* zr;
    
    phi     =   1. ./ zden;
    
end;